export interface EtcdOptions {
}
export declare class Etcd {
    servers: string[];
    options: EtcdOptions;
    credentials: any;
    clients: any;
    constructor(servers?: string[], options?: EtcdOptions);
    private getBuffer(obj);
    private callClient(client, method, arg);
    /**
     * blocking version of get()
     * @see {@link get}
     */
    getSync(key: string): string;
    /**
     * get a key from etcd
     * @param key - key to get
     * @return value of the key
     */
    get(key: string): Promise<string>;
    /**
     * blocking version of range()
     * @see {@link range}
     */
    rangeSync(fromKey: string, toKey: string): any;
    /**
     * get a range of key from etcd
     * @param fromKey - key to start from
     * @param toKey - key to end on
     * @return value of the key
     */
    range(fromKey: string, toKey: string): Promise<any>;
    /**
     * blocking version of set()
     * @see {@link set}
     */
    setSync(key: string, value: any): boolean;
    /**
     * set a key/value to etcd.
     * * a `Buffer` is saved as-is
     * * `null` is saved as an empty string
     * * `undefined` is saved as an empty string
     * * strings are saved as-is
     * * everthing else is tried to `JSON.stringify(value)`
     * @param key - etcd key to set
     * @param value - content to set
     * @return `true`
     */
    set(key: string, value: any): Promise<boolean>;
    /**
     * blocking version of delete()
     * @see {@link delete}
     */
    deleteSync(key: string, keyTo?: string): number;
    /**
     * delete a key from etcd.
     * @param key - etcd key to delete
     * @return number of keys deleted
     */
    delete(key: string, keyTo?: string): Promise<number>;
}
